@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Fits.py
-Version : 1.2.0
+Version : 1.2.1
 Author  : Stefano Covino
-Date    : 14/02/2012
+Date    : 31/03/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -25,6 +25,7 @@ History : (12/10/2010) First version.
         : (25/04/2011) Output and input file names can be different.
         : (27/04/2011) Always list in output. Keywords longer than 8 characters.
         : (14/02/2012) Possibilty to write in other extensions.
+        : (31/03/2013) Value considered float unless it is not possible to convert it.
 
 """
 
@@ -41,7 +42,11 @@ def AddHeaderEntry (fitsfile, keylist, entrylist, commentlist, outfilename=None,
     heder = hdr[ext].header    
     for i,l,m in zip(keylist,entrylist,commentlist):
         try:
-            heder.update(i,l,m)
+            lf = float(l)
+        except ValueError:
+            lf = l
+        try:
+            heder.update(i,lf,m)
         except ValueError:
             heder.update(i.split()[0][:8],l,m)
     #
