@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Math
-Version : 1.1.0
+Version : 1.1.1
 Author  : Stefano Covino
-Date    : 23/08/2012
+Date    : 20/09/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -19,11 +19,12 @@ History : (29/09/2010) First named version.
         : (11/02/2012) PointMatch added.
         : (18/02/2012) Sky functions moved to SRPSky.
         : (23/08/2012) New angular distance function.
+        : (20/09/2012) Angular phasing function.
 """
 
 
 __all__ = ['AngularDistance', 'AstroAngleInput', 'AstroCoordInput', 'AstroMagInput', 'CartesiamCoordAmpRotoTranslation', 
             'CartesianDistance', 'CartesianVectorClass', 'FastAngularDistance', 'InverseCartesiamCoordAmpRotoTranslation', 
-            'MinDist', 'PointClass', 'PointMatch', 'TriangleClass', 'TriangleMatch']
+            'MinDist', 'PhaseAngle', 'PointClass', 'PointMatch', 'TriangleClass', 'TriangleMatch']
 
 
