@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Sky
-Version : 1.0.0
+Version : 1.0.1
 Author  : Stefano Covino
-Date    : 18/02/2012
+Date    : 02/09/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -14,9 +14,11 @@ Usage   : to be imported
 Remarks :
 
 History : (18/02/2012) First named version.
+        : (02/09/2013) New functions.
 """
 
 
-__all__ = ['HourAngle','ParallacticAngle','SiderealTime']
+__all__ = ['AltitudeRate','AzimuthRate','HourAngle','ParallacticAngle','ParallacticAngleRate',
+            'SiderealTime']
 
 
