@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Spectroscopy
-Version : 1.4.1
+Version : 1.6.0
 Author  : Stefano Covino
-Date    : 20/12/2012
+Date    : 02/04/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -18,14 +18,16 @@ History : (17/11/2010) First named version.
         : (27/10/2011) FWHM variation with airmass and wavelength
         : (22/08/2012) Atmospheric extinction curves
         : (20/12/2012) New atmospheric extinction curves.
+        : (22/03/2013) GetSpectrum.
+        : (02/04/2013) GetSpectrumPosition.
 """
 
 
 __all__ = ['Air2Vacuum', 'AirRefrIndex', 'AtmExtinction', 'CalzettiExt', 'DLACrossSection', 'Ecm2sA2Jy', 'ExtConstants', 
-    'FWHMvsZL', 'getAbs', 'I_Totani', 'Jy2Ecm2sA', 'LymAlphaDumpConst', 'LyAlphaProfile', 'OzonVertExt', 'RaleyghScattering', 
-    'Ralpha', 'SolarAbundance', 'StndCriticalDens', 'TauDLA', 'TauDLAVoigt', 'TauGP', 'TauIGM', 'TauVoigt', 'Transitions', 
-    'Vacuum2Air', 'VoigtFunct', 'VoigtFunctApprox', 'VoigtFunctApproxA', 'VoigtFunctTG', 'VoigtFunctWells', 
-    'VoigtIntegrand', 'VoigtProfileCmpd', 'VoigtProfileWells']
+    'FWHMvsZL', 'getAbs', 'GetSpectrum', 'GetSpectrumPosition', 'I_Totani', 'Jy2Ecm2sA', 'LymAlphaDumpConst', 
+    'LyAlphaProfile', 'OzonVertExt', 'RaleyghScattering', 'Ralpha', 'SolarAbundance', 'StndCriticalDens', 'TauDLA', 
+    'TauDLAVoigt', 'TauGP', 'TauIGM', 'TauVoigt', 'Transitions', 'Vacuum2Air', 'VoigtFunct', 'VoigtFunctApprox', 
+    'VoigtFunctApproxA', 'VoigtFunctTG', 'VoigtFunctWells', 'VoigtIntegrand', 'VoigtProfileCmpd', 'VoigtProfileWells']
 
 
 import math
